{ Component TNetInfo.  Version 1.0, Date 19. Jan 1999

  Gets the MS-Client network configuration data
  by reading out the values in the registry.

  Properties (all Read-only):
   ComputerName       :String     Name of the Computer for MS Network Client.
   Workgroup          :String     Name of the Workgroup for MS Network Client.
   Comment            :String     Comment for the Machine in the MS Network Client.

   NTDomain           :Boolean    True if connected to a NT Domain.
   NTDomainName       :String     Name of the Authenticating Domain the Computer is connected to.
                                  Empty if not connected to a NT Domain.

   Procedure Update;              Re-Reads the Data out of the registry.
                                  Usually not needed (see below)

  The values are read out of the registry when the component
  gets created. As the network configuration data is not likely
  to be changed @runtime, the "Update" Procedure is rather obsolete;
  nevertheless, you can call this procedure if you want to take
  care that you read the most current network config.

  This Component can easily be extended for Netware Network Client info.
  If you have a look at this component's source, you simply have to
  replace the 'MSNP32' by 'NWNP32' and look what information is available
  under the 'new' nw-compliant registry entries.


  This Component is FreeWare. No charges. No warranties. Use on your
  own Risk. Source included.

  Developed for Delphi3, should also run on Delphi2 and Delphi4.

  If you enhance this component for further network config data,
  please send me a copy so that I can keep this component up-to-date.


  If you have comments, feel free to contact me:

  Stefan Gebers, Gelit@compuserve.com

}
unit NetInfo;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Registry;

type
  TNetInfo = class(TComponent)
  private
    { Private-Deklarationen }
    FComputerName,
    FWorkGroupName,
    FComment,
    FNTDomain:String;
    FConnectedToNT:Boolean;

    Procedure ReadNetworkData;

    Procedure SetComputerName(Value:String);
    Procedure SetNTDomain(Value:boolean);

  protected
    { Protected-Deklarationen }

  public
    { Public-Deklarationen }
    Constructor Create(AOwner:TComponent); override;
    Destructor Destroy; override;

    Procedure Update;


  published
    { Published-Deklarationen }
    property ComputerName:String read fcomputername write SetComputerName;
    property WorkGroup:String read fworkgroupname write SetComputerName;
    property Comment:string read fcomment write SetComputerName;
    property NTDomain:boolean read fconnectedtoNT write SetNTDomain;
    property NTDomainName:String read Fntdomain write SetComputerName;
  end;

procedure Register;

implementation

Procedure TNetInfo.SetComputerName(Value:String);
begin
//Simply do nothing... Value is readonly, remember?
end;

Procedure TNetInfo.SetNtDomain(Value:Boolean);
begin
//Simply do nothing... Value is readonly, remember?
end;


Procedure TNetInfo.Update;
begin
  ReadNetworkData;
end;

Constructor TNetInfo.Create(AOwner:TComponent);
begin
 inherited Create(AOwner);

 ReadNetworkData;
end;

Destructor TNetInfo.Destroy;
begin
 inherited Destroy;
end;

Procedure TNetInfo.ReadNetworkData;
var regini:TRegIniFile;
begin

  regini:=TRegIniFile.Create(''); {no standard key...}

  regini.RootKey:=HKEY_LOCAL_MACHINE;
  regini.OpenKey('SYSTEM\CURRENTCONTROLSET\SERVICES\VxD', false);
  fComputerName:=regini.ReadString('VNetSup', 'ComputerName', '');
  fComment:=regini.ReadString('VNetSup', 'Comment', '');
  fWorkgroupName:=regini.ReadString('VNetSup', 'WorkGroup', '');
  regini.CloseKey;

  {The key for NetWare Servers is NWNP32 instead of MSNP32 }

  regini.OpenKey('System\CurrentControlSet\Services\MSNP32', false);
  fNTDomain:=regini.ReadString('NetWorkProvider', 'AuthenticatingAgent', '');
  fConnectedToNT:=fNTDomain>'';
  regini.CloseKey;

  regini.free;


end;


procedure Register;
begin
  RegisterComponents('Win32', [TNetInfo]);
end;

end.
